Check if an AEMET API Key is present for the current session
Source:R/aemet-api-key.R
aemet_detect_api_key.RdDetects whether an API key is available in the current session:
If an API key is already set as an environment variable, it is preserved.
If no environment variable is set and an API key has been stored permanently via
aemet_api_key(), it is loaded.
See also
Other aemet_auth:
aemet_api_key()