| climatestripes_station | R Documentation |
Plot a climate stripes graph for a station.
climatestripes_station(
station,
start = 1950,
end = 2020,
with_labels = "yes",
verbose = FALSE,
...
)
station |
Character string with station identifier code(s). See
|
start |
Numeric value with the start year (format: |
end |
Numeric value with the end year (format: |
with_labels |
Character string, either |
verbose |
Logical. If |
... |
Arguments passed on to
|
A ggplot2 object. See help("ggplot2").
You need to set your API key globally using aemet_api_key().
Query timeout can be controlled with
options(climaemet_timeout = 60) (default value). See
httr2::req_timeout() for details.
"Warming stripes" charts are a conceptual idea of Professor Ed Hawkins (University of Reading) and are specifically designed to be as simple as possible and to warn about climate change risks. For more details, see ShowYourStripes.
ggstripes()
Plotting functions:
climatogram_normal(),
climatogram_period(),
ggclimat_walter_lieth(),
ggstripes(),
ggwindrose(),
windrose_days(),
windrose_period()
Warming stripes functions:
climaemet_9434_temp,
ggstripes()
# Do not run this example.
if (FALSE) {
# Downloading data may take a few minutes.
climatestripes_station(
"9434",
start = 2020,
end = 2024,
with_labels = "yes",
col_pal = "Inferno"
)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.