R/helpers.R
day_of_year.Rd
Returns the first or last calendar day of a year.
first_day_of_year(year = NULL) last_day_of_year(year = NULL)
A numeric year in YYYY format.
YYYY
A character string containing a date in YYYY-MM-DD format.
YYYY-MM-DD
first_day_of_year(2000) #> [1] "2000-01-01" last_day_of_year(2020) #> [1] "2020-12-31"
Site built with pkgdown 2.2.0.
Template rostemplate by dieghernan, based on Universal Theme for Hugo.