Retrieves climatology values for one station or all available stations.
aemet_daily_period() and aemet_daily_period_all() are shortcuts for
aemet_daily_clim().
Usage
aemet_daily_clim(
station = "all",
start = Sys.Date() - 7,
end = Sys.Date(),
verbose = FALSE,
return_sf = FALSE,
extract_metadata = FALSE,
progress = TRUE
)
aemet_daily_period(
station,
start = as.integer(format(Sys.Date(), "%Y")),
end = start,
verbose = FALSE,
return_sf = FALSE,
extract_metadata = FALSE,
progress = TRUE
)
aemet_daily_period_all(
start = as.integer(format(Sys.Date(), "%Y")),
end = start,
verbose = FALSE,
return_sf = FALSE,
extract_metadata = FALSE,
progress = TRUE
)Arguments
- station
A character vector of station identifiers (see
aemet_stations()) or"all"for all stations.- start, end
Character strings containing the start and end dates. See Details.
- verbose
A logical value. If
TRUE, displays information about the exchange between the client and server.- return_sf
A logical value. If
TRUE, the function returns ansfspatial object. IfFALSE(the default), it returns a tibble. sf must be installed.- extract_metadata
A logical value. If
TRUE, returns a tibble describing the response fields. Seeget_metadata_aemet().- progress
A logical value. If
TRUE, displays acli::cli_progress_bar()unlessverbose = TRUE.
Details
For aemet_daily_clim(), start and end must be Date objects or
strings in YYYY-MM-DD format, such as "2020-12-31", that can be coerced
with as.Date(). For aemet_daily_period() and
aemet_daily_period_all(), they must be strings representing the years to
extract, such as "2018" and "2020".
API key
Queries to the AEMET OpenData API require an API key. Use aemet_api_key()
to set it globally. Query timeout can be controlled with
options(climaemet_timeout = 60) (default value). See
httr2::req_timeout() for details.
See also
aemet_stations() for station identifiers.
Climatology:
aemet_extremes_clim(),
aemet_monthly_clim(),
aemet_normal_clim()
Examples
library(dplyr)
obs <- aemet_daily_clim(c("9434", "3195"))
glimpse(obs)
#> Rows: 8
#> Columns: 27
#> $ fecha <date> 2026-08-21, 2026-08-22, 2026-08-23, 2026-08-24, 2026-08-2…
#> $ indicativo <chr> "9434", "9434", "9434", "9434", "3195", "3195", "3195", "3…
#> $ nombre <chr> "ZARAGOZA, AEROPUERTO", "ZARAGOZA, AEROPUERTO", "ZARAGOZA,…
#> $ provincia <chr> "ZARAGOZA", "ZARAGOZA", "ZARAGOZA", "ZARAGOZA", "MADRID", …
#> $ altitud <dbl> 249, 249, 249, 249, 667, 667, 667, 667
#> $ tmed <dbl> 24.0, 24.8, 27.8, 29.0, 25.4, 26.0, 27.2, 23.4
#> $ prec <dbl> 0.0, 0.0, 1.2, 0.0, 0.0, 0.0, 0.0, 0.0
#> $ tmin <dbl> 19.3, 18.1, 21.9, 22.5, 20.2, 20.1, 21.7, 19.7
#> $ horatmin <time> 05:20:00, 04:00:00, 02:20:00, 06:10:00, 06:40:00, 06:00:00…
#> $ tmax <dbl> 28.7, 31.5, 33.8, 35.6, 30.7, 32.0, 32.7, 27.2
#> $ horatmax <time> 14:50:00, 15:30:00, 16:10:00, 13:20:00, 14:50:00, 13:30:00…
#> $ dir <chr> "31", "12", "13", "27", "26", "05", "22", "24"
#> $ velmedia <dbl> 5.3, 4.7, 5.3, 6.9, 1.7, 2.5, 2.2, 4.2
#> $ racha <dbl> 12.2, 12.5, 13.6, 15.3, 7.5, 9.2, 8.9, 13.1
#> $ horaracha <chr> "07:20", "Varias", "17:00", "15:30", "13:30", "03:30", "15…
#> $ sol <dbl> 12.9, 6.0, 8.5, 10.9, NA, NA, NA, NA
#> $ presMax <dbl> 987.6, 987.5, 987.0, 983.7, 939.6, 939.4, 940.6, 939.4
#> $ horaPresMax <chr> "23", "07", "07", "00", "09", "09", "Varias", "24"
#> $ presMin <dbl> 982.7, 982.8, 981.8, 978.4, 936.9, 936.6, 936.2, 936.6
#> $ horaPresMin <chr> "02", "16", "17", "16", "Varias", "18", "18", "15"
#> $ hrMedia <dbl> 49, 52, 60, 37, 44, 41, 43, 41
#> $ hrMax <dbl> 81, 80, 88, 86, 68, 66, 72, 69
#> $ horaHrMax <time> 02:20:00, 23:59:00, 02:20:00, 06:30:00, 05:30:00, 07:10:00…
#> $ hrMin <dbl> 32, 40, 36, 8, 27, 28, 25, 30
#> $ horaHrMin <chr> "16:30", "11:10", "14:50", "13:00", "Varias", "Varias", "…
#> $ pintMax <dbl> 0.0, 0.0, 4.8, 0.0, 0.0, 0.0, 0.0, 0.0
#> $ horaPIntMax <time> NA, NA, 17:46:00, NA, NA, NA…
# Metadata.
meta <- aemet_daily_clim(c("9434", "3195"), extract_metadata = TRUE)
glimpse(meta$campos)
#> List of 27
#> $ :List of 4
#> ..$ id : chr "fecha"
#> ..$ descripcion: chr "fecha del dia (AAAA-MM-DD)"
#> ..$ tipo_datos : chr "string"
#> ..$ requerido : logi TRUE
#> $ :List of 4
#> ..$ id : chr "indicativo"
#> ..$ descripcion: chr "indicativo climatológico"
#> ..$ tipo_datos : chr "string"
#> ..$ requerido : logi TRUE
#> $ :List of 4
#> ..$ id : chr "nombre"
#> ..$ descripcion: chr "nombre (ubicación) de la estación"
#> ..$ tipo_datos : chr "string"
#> ..$ requerido : logi TRUE
#> $ :List of 4
#> ..$ id : chr "provincia"
#> ..$ descripcion: chr "provincia de la estación"
#> ..$ tipo_datos : chr "string"
#> ..$ requerido : logi TRUE
#> $ :List of 5
#> ..$ id : chr "altitud"
#> ..$ descripcion: chr "altitud de la estación en m sobre el nivel del mar"
#> ..$ tipo_datos : chr "float"
#> ..$ unidad : chr "m"
#> ..$ requerido : logi TRUE
#> $ :List of 5
#> ..$ id : chr "tmed"
#> ..$ descripcion: chr "Temperatura media diaria"
#> ..$ tipo_datos : chr "float"
#> ..$ unidad : chr "°C"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "prec"
#> ..$ descripcion: chr "Precipitación diaria de 07 a 07"
#> ..$ tipo_datos : chr "float"
#> ..$ unidad : chr "mm (Ip = inferior a 0,1 mm) (Acum = Precipitación acumulada)"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "tmin"
#> ..$ descripcion: chr "Temperatura Mínima del día"
#> ..$ tipo_datos : chr "float"
#> ..$ unidad : chr "°C"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "horatmin"
#> ..$ descripcion: chr "Hora y minuto de la temperatura mínima"
#> ..$ tipo_datos : chr "string"
#> ..$ unidad : chr "UTC"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "tmax"
#> ..$ descripcion: chr "Temperatura Máxima del día"
#> ..$ tipo_datos : chr "float"
#> ..$ unidad : chr "°C"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "horatmax"
#> ..$ descripcion: chr "Hora y minuto de la temperatura máxima"
#> ..$ tipo_datos : chr "string"
#> ..$ unidad : chr "UTC"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "dir"
#> ..$ descripcion: chr "Dirección de la racha máxima"
#> ..$ tipo_datos : chr "float"
#> ..$ unidad : chr "decenas de grado (99 = dirección variable)(88 = sin dato)"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "velmedia"
#> ..$ descripcion: chr "Velocidad media del viento"
#> ..$ tipo_datos : chr "float"
#> ..$ unidad : chr "m/s"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "racha"
#> ..$ descripcion: chr "Racha máxima del viento"
#> ..$ tipo_datos : chr "float"
#> ..$ unidad : chr "m/s"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "horaracha"
#> ..$ descripcion: chr "Hora y minuto de la racha máxima"
#> ..$ tipo_datos : chr "string"
#> ..$ unidad : chr "UTC"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "sol"
#> ..$ descripcion: chr "Insolación"
#> ..$ tipo_datos : chr "float"
#> ..$ unidad : chr "horas"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "presmax"
#> ..$ descripcion: chr "Presión máxima al nivel de referencia de la estación"
#> ..$ tipo_datos : chr "float"
#> ..$ unidad : chr "hPa"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "horapresmax"
#> ..$ descripcion: chr "Hora de la presión máxima (redondeada a la hora entera más próxima)"
#> ..$ tipo_datos : chr "string"
#> ..$ unidad : chr "UTC"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "presmin"
#> ..$ descripcion: chr "Presión mínima al nivel de referencia de la estación"
#> ..$ tipo_datos : chr "float"
#> ..$ unidad : chr "hPa"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "horapresmin"
#> ..$ descripcion: chr "Hora de la presión mínima (redondeada a la hora entera más próxima)"
#> ..$ tipo_datos : chr "string"
#> ..$ unidad : chr "UTC"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "hrmedia"
#> ..$ descripcion: chr "Humedad relativa media diaria"
#> ..$ tipo_datos : chr "float"
#> ..$ unidad : chr "%"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "hrmax"
#> ..$ descripcion: chr "Humedad relativa máxima diaria"
#> ..$ tipo_datos : chr "float"
#> ..$ unidad : chr "%"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "horahrmax"
#> ..$ descripcion: chr "Hora de la humedad relativa máxima diaria"
#> ..$ tipo_datos : chr "string"
#> ..$ unidad : chr "UTC"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "hrmin"
#> ..$ descripcion: chr "Humedad relativa mínima diaria"
#> ..$ tipo_datos : chr "float"
#> ..$ unidad : chr "%"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "horahrmin"
#> ..$ descripcion: chr "Hora de la humedad relativa mínima diaria"
#> ..$ tipo_datos : chr "string"
#> ..$ unidad : chr "UTC"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "pintmax"
#> ..$ descripcion: chr "Intensidad máxima de precipitación"
#> ..$ tipo_datos : chr "float"
#> ..$ unidad : chr "mm/h (-0,3 = precipitación inapreciable < 0,1 mm/h)"
#> ..$ requerido : logi FALSE
#> $ :List of 5
#> ..$ id : chr "horapintmax"
#> ..$ descripcion: chr "Hora de la intensidad máxima de precipitación"
#> ..$ tipo_datos : chr "string"
#> ..$ unidad : chr "UTC"
#> ..$ requerido : logi FALSE