View source: R/aemet-api-key.R
| aemet_detect_api_key | R Documentation |
Detects whether an API key is available in the current session:
If an API key is already set as an environment variable, it is preserved.
If no environment variable is set and an API key has been stored
permanently via aemet_api_key(), it is loaded.
aemet_detect_api_key(...)
aemet_show_api_key(...)
... |
Ignored. |
TRUE or FALSE. aemet_show_api_key() displays your stored API keys.
Other aemet_auth:
aemet_api_key()
aemet_detect_api_key()
# CAUTION: This may reveal API Keys
if (FALSE) {
aemet_show_api_key()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.