aemet_forecast_fires: AEMET wildfire risk forecast

View source: R/aemet-forecast-fires.R

aemet_forecast_firesR Documentation

AEMET wildfire risk forecast

Description

Get a SpatRaster with the daily wildfire risk level.

Usage

aemet_forecast_fires(
  area = c("p", "c"),
  verbose = FALSE,
  extract_metadata = FALSE
)

Arguments

area

Forecast area. Accepted values are:

  • "p" for mainland Spain and Balearic Islands.

  • "c" for Canary Islands.

verbose

Logical. If TRUE, provides information about the flow of information between the client and server.

extract_metadata

Logical. If TRUE, the output is a tibble with the description of the fields. See also get_metadata_aemet().

Details

The SpatRaster provides six factor() levels with the following meaning:

  • "1": Very low risk.

  • "2": Low risk.

  • "3": Moderate risk.

  • "4": High risk.

  • "5": Very high risk.

  • "6": Extreme risk.

The resulting object has several layers, each one representing the forecast for the upcoming 7 days. It also has additional attributes provided by the terra package, such as terra::time() and terra::coltab().

Value

A tibble or a SpatRaster.

https://www.aemet.es/en/eltiempo/prediccion/incendios.

See Also

AEMET data functions: aemet_alert_zones(), aemet_alerts(), aemet_beaches(), aemet_daily_clim(), aemet_extremes_clim(), aemet_forecast_beaches(), aemet_forecast_daily(), aemet_last_obs(), aemet_monthly, aemet_normal, aemet_stations()

Forecast functions: aemet_forecast_beaches(), aemet_forecast_daily(), aemet_forecast_tidy()

Examples


aemet_forecast_fires(extract_metadata = TRUE)

# Extract alerts.
alerts <- aemet_forecast_fires()

alerts

# Plot with terra.
library(terra)
plot(alerts, all_levels = TRUE)

# Zoom in on an area.
cyl <- mapSpain::esp_get_ccaa("Castilla y Leon", epsg = 4326)

# SpatVector
cyl <- vect(cyl)

fires_cyl <- crop(alerts, cyl)
title <- names(fires_cyl)[1]

plot(fires_cyl[[1]], main = title, all_levels = TRUE)
plot(cyl, add = TRUE)


climaemet documentation built on June 3, 2026, 5:07 p.m.