climaemet-package: climaemet: Tools for AEMET Climate Data

climaemet-packageR Documentation

climaemet: Tools for AEMET Climate Data

Description

logo

Download meteorological and climate data from the Spanish Meteorological Agency (AEMET) directly in R using the AEMET API. Create scientific visualizations, including climate charts, climate time series trend analyses, temperature and precipitation anomaly maps, warming stripes and climatograms.

Author(s)

Maintainer: Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID)

Authors:

Other contributors:

  • AEMET (ROR) [copyright holder]

See Also

Useful links:


climaemet documentation built on June 3, 2026, 5:07 p.m.