climaemet: Access and Visualize AEMET Weather and Climate Data
Source:R/climaemet-package.R
climaemet-package.RdProvides access to meteorological observations, forecasts, alerts and climatology data from the Spanish Meteorological Agency (AEMET) through the 'AEMET OpenData' API https://opendata.aemet.es/. Includes tools for working with tabular and spatial data and for creating Walter-Lieth climate diagrams, warming stripes and wind roses.
Author
Maintainer: Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID)
Authors:
Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID)
Manuel Pizarro (ORCID) [copyright holder]
Gema Fernández-Avilés (ORCID)
Other contributors:
AEMET (ROR) [copyright holder]