Download meteorological and climatological data from the Spanish Meteorological Agency (AEMET) directly in R using the AEMET API. Create scientific visualizations, including climate charts, trend analyses of climate time series, temperature and precipitation anomaly maps, warming stripes and climatograms.
Author
Maintainer: Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID)
Authors:
Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID)
Manuel Pizarro (ORCID) [copyright holder]
Gema Fernández-Avilés (ORCID)
Other contributors:
AEMET (ROR) [copyright holder]