Walter-Lieth climate diagram from climatological normals
Source:R/climatogram.R
climatogram_normal.RdPlots a Walter-Lieth climate diagram from climatological normal values for a station. The diagram summarizes local climate conditions for 1981–2010.
Arguments
- station
A character vector of station identifiers. See
aemet_stations().- labels
A character string specifying the language for the x-axis month labels, such as
"en"(English),"es"(Spanish) or"fr"(French).- verbose
A logical value. If
TRUE, displays information about the exchange between the client and server.- ggplot2
A logical value. If
TRUE, the function usesggclimat_walter_lieth(). IfFALSE, it usesclimatol::diagwl().- ...
Further arguments passed to
climatol::diagwl()orggclimat_walter_lieth(), depending on the value ofggplot2.
Note
The implementation is based on climatol.
API key
Queries to the AEMET OpenData API require an API key. Use aemet_api_key()
to set it globally. Query timeout can be controlled with
options(climaemet_timeout = 60) (default value). See
httr2::req_timeout() for details.
References
Walter, H. K., Harnickell, E., Lieth, F. H. H. and Rehder, H. (1967). Klimadiagramm-weltatlas. Jena: Fischer.
Guijarro J. A. (2023). climatol: Climate Tools (Series Homogenization and Derived Products). R package version 4.0.0, https://climatol.eu.
See also
Walter-Lieth climate diagrams:
climatogram_period(),
ggclimat_walter_lieth()
Examples
climatogram_normal("9434")
#> ! HTTP `429`:
#> Límite de peticiones o caudal por minuto excedido para este usuario. Espere
#> al siguiente minuto.
#> ℹ Retrying.
#> Waiting 3s for retry backoff ■■■■■■■■■■■■
#> Waiting 3s for retry backoff ■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■
#> Waiting 3s for retry backoff ■■■■■■■■■■
#> Waiting 3s for retry backoff ■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■
#> Waiting 12s for retry backoff ■■■
#> Waiting 12s for retry backoff ■■■■■■■■
#> Waiting 12s for retry backoff ■■■■■■■■■■■■■■■
#> Waiting 12s for retry backoff ■■■■■■■■■■■■■■■■■■■■■■■
#> Waiting 12s for retry backoff ■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■
#> Waiting 12s for retry backoff ■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■
#>