climatogram_period: Walter & Lieth climatic diagram for a time period

View source: R/climatogram.R

climatogram_periodR Documentation

Walter & Lieth climatic diagram for a time period

Description

Plot a Walter & Lieth climatic diagram from monthly climatology values for a station. This climatogram is a great way to show a summary of climate conditions for a place over a specific time period.

Usage

climatogram_period(
  station = NULL,
  start = 1990,
  end = 2020,
  labels = "en",
  verbose = FALSE,
  ggplot2 = TRUE,
  ...
)

Arguments

station

Character string with station identifier code(s). See aemet_stations().

start

Numeric value with the start year (format: YYYY).

end

Numeric value with the end year (format: YYYY).

labels

Character string with month labels for the x-axis: "en" (English), "es" (Spanish), "fr" (French), etc.

verbose

Logical. If TRUE, provides information about the flow of information between the client and server.

ggplot2

Logical. If TRUE, the function uses ggclimat_walter_lieth(). If FALSE, it uses climatol::diagwl().

...

Further arguments passed to climatol::diagwl() or ggclimat_walter_lieth(), depending on the value of ggplot2.

Value

A plot.

API key

You need to set your API key globally using aemet_api_key(). Query timeout can be controlled with options(climaemet_timeout = 60) (default value). See httr2::req_timeout() for details.

Note

The code is based on code from the CRAN package climatol.

References

  • Walter, H. K., Harnickell, E., Lieth, F. H. H., & Rehder, H. (1967). Klimadiagramm-weltatlas. Jena: Fischer, 1967.

  • Guijarro J. A. (2023). climatol: Climate Tools (Series Homogenization and Derived Products). R package version 4.0.0, https://climatol.eu.

See Also

Plotting functions: climatestripes_station(), climatogram_normal(), ggclimat_walter_lieth(), ggstripes(), ggwindrose(), windrose_days(), windrose_period()

Climatogram functions: climaemet_9434_climatogram, climatogram_normal(), ggclimat_walter_lieth()

Examples



climatogram_period("9434", start = 2015, end = 2020, labels = "en")



climaemet documentation built on June 3, 2026, 5:07 p.m.