| climatogram_period | R Documentation |
Plot a Walter & Lieth climatic diagram from monthly climatology values for a station. This climatogram is a great way to show a summary of climate conditions for a place over a specific time period.
climatogram_period(
station = NULL,
start = 1990,
end = 2020,
labels = "en",
verbose = FALSE,
ggplot2 = TRUE,
...
)
station |
Character string with station identifier code(s). See
|
start |
Numeric value with the start year (format: |
end |
Numeric value with the end year (format: |
labels |
Character string with month labels for the x-axis: |
verbose |
Logical. If |
ggplot2 |
Logical. If |
... |
Further arguments passed to
|
A plot.
You need to set your API key globally using aemet_api_key().
Query timeout can be controlled with
options(climaemet_timeout = 60) (default value). See
httr2::req_timeout() for details.
The code is based on code from the CRAN package climatol.
Walter, H. K., Harnickell, E., Lieth, F. H. H., & Rehder, H. (1967). Klimadiagramm-weltatlas. Jena: Fischer, 1967.
Guijarro J. A. (2023). climatol: Climate Tools (Series Homogenization and Derived Products). R package version 4.0.0, https://climatol.eu.
Plotting functions:
climatestripes_station(),
climatogram_normal(),
ggclimat_walter_lieth(),
ggstripes(),
ggwindrose(),
windrose_days(),
windrose_period()
Climatogram functions:
climaemet_9434_climatogram,
climatogram_normal(),
ggclimat_walter_lieth()
climatogram_period("9434", start = 2015, end = 2020, labels = "en")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.