| ggstripes | R Documentation |
Plot different "climate stripes" or "warming stripes" using ggplot2. These graphics are visual representations of the change in temperature as measured in each location over the past 70-100+ years. Each stripe represents the temperature in that station averaged over a year.
ggstripes(
data,
plot_type = "stripes",
plot_title = "",
n_temp = 11,
col_pal = "RdBu",
...
)
data |
A data.frame with date ( |
plot_type |
Plot type. Accepted values are |
plot_title |
Character string to be used for the plot title. |
n_temp |
Numeric value with the number of colors of the palette.
(default |
col_pal |
Character string indicating the name of the
|
... |
Further arguments passed to |
A ggplot2 object. See help("ggplot2").
You need to set your API key globally using aemet_api_key().
Query timeout can be controlled with
options(climaemet_timeout = 60) (default value). See
httr2::req_timeout() for details.
"Warming stripes" charts are a conceptual idea of Professor Ed Hawkins (University of Reading) and are specifically designed to be as simple as possible and to warn about climate change risks. For more details, see ShowYourStripes.
climatestripes_station(), ggplot2::theme() for more possible
arguments to pass to ggstripes().
Plotting functions:
climatestripes_station(),
climatogram_normal(),
climatogram_period(),
ggclimat_walter_lieth(),
ggwindrose(),
windrose_days(),
windrose_period()
Warming stripes functions:
climaemet_9434_temp,
climatestripes_station()
library(ggplot2)
data <- climaemet::climaemet_9434_temp
ggstripes(data, plot_title = "Zaragoza Airport") +
labs(subtitle = "(1950-2020)")
ggstripes(data, plot_title = "Zaragoza Airport", plot_type = "trend") +
labs(subtitle = "(1950-2020)")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.