| windrose_days | R Documentation |
Plot a windrose showing the wind speed and direction for a station over a period of days.
windrose_days(
station,
start = "2000-12-01",
end = "2000-12-31",
n_directions = 8,
n_speeds = 5,
speed_cuts = NA,
col_pal = "GnBu",
calm_wind = 0,
legend_title = "Wind speed (m/s)",
verbose = FALSE
)
station |
Character string with station identifier code(s) (see
|
start |
Character string with the start date (format: |
end |
Character string with the end date (format: |
n_directions |
Numeric value with the number of direction bins to plot
(petals on the rose). Valid values are |
n_speeds |
Numeric value with the number of equally spaced wind speed
bins to plot. This is used if |
speed_cuts |
Numeric vector with the cut points for the wind speed
intervals, or |
col_pal |
Character string indicating the name of the
|
calm_wind |
Numeric value with the upper limit for wind speed that is
considered calm (default |
legend_title |
Character string to be used for the legend title. |
verbose |
Logical. If |
A ggplot2 object. See help("ggplot2").
You need to set your API key globally using aemet_api_key().
Query timeout can be controlled with
options(climaemet_timeout = 60) (default value). See
httr2::req_timeout() for details.
aemet_daily_clim()
Plotting functions:
climatestripes_station(),
climatogram_normal(),
climatogram_period(),
ggclimat_walter_lieth(),
ggstripes(),
ggwindrose(),
windrose_period()
Wind functions:
climaemet_9434_wind,
ggwindrose(),
windrose_period()
windrose_days("9434",
start = "2000-12-01",
end = "2000-12-31",
speed_cuts = 4
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.