Windrose (speed/direction) diagram of a station over a time period
Source:R/windrose.R
windrose_period.RdPlot a windrose showing the wind speed and direction for a station over a time period.
Usage
windrose_period(
station,
start = 2000,
end = 2010,
n_directions = 8,
n_speeds = 5,
speed_cuts = NA,
col_pal = "GnBu",
calm_wind = 0,
legend_title = "Wind speed (m/s)",
verbose = FALSE
)Arguments
- station
Character string with station identifier code(s). See
aemet_stations().- start
Numeric value with the start year (format:
YYYY).- end
Numeric value with the end year (format:
YYYY).- n_directions
Numeric value with the number of direction bins to plot (petals on the rose). Valid values are
4,8or16.- n_speeds
Numeric value with the number of equally spaced wind speed bins to plot. This is used if
speed_cutsisNA(default5).- speed_cuts
Numeric vector with the cut points for the wind speed intervals, or
NA(default).- col_pal
Character string indicating the name of the
hcl.pals()color palette to be used for plotting.- calm_wind
Numeric value with the upper limit for wind speed that is considered calm (default
0).- legend_title
Character string to be used for the legend title.
- verbose
Logical. If
TRUE, provides information about the flow of information between the client and server.
Value
A ggplot2 object. See help("ggplot2").
API key
You need to set your API key globally using aemet_api_key().
Query timeout can be controlled with
options(climaemet_timeout = 60) (default value). See
httr2::req_timeout() for details.
See also
Plotting functions:
climatestripes_station(),
climatogram_normal(),
climatogram_period(),
ggclimat_walter_lieth(),
ggstripes(),
ggwindrose(),
windrose_days()
Wind functions:
climaemet_9434_wind,
ggwindrose(),
windrose_days()